@@ -4,9 +4,9 @@ module Rack
   module OAuth2
     module Server
       class Token < Abstract::Handler
-        def call(env)
+        def _call(env)
           request = Request.new(env)
-          grant_type_for(request).new(&@authenticator).call(env).finish
+          grant_type_for(request).new(&@authenticator)._call(env).finish
         rescue Rack::OAuth2::Server::Abstract::Error => e
           e.finish
         end
